==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Translate/ts/Translate_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>Translate</name>
    <message>
        <location filename="../Translate.js" line="+44"/>
        <source>Modify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Move/Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Reference point</source>
        <translation>基準点</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Target point</source>
        <translation>ターゲット点</translation>
    </message>
    <message>
        <location filename="../TranslateInit.js" line="+2"/>
        <source>&amp;Move / Copy</source>
        <translation>&amp;M 移動/コピー</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Move or copy entities once or multiple times</source>
        <translation>１回または複数回の移動またはコピー</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Use dialog for tool options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Translate.ui" line="+17"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use current layer and &amp;attributes</source>
        <translation type="unfinished">&amp;a 現在の画層と属性を使用</translation>
    </message>
</context>
<context>
    <name>TranslateOptions</name>
    <message>
        <location filename="../TranslateDialog.ui" line="+14"/>
        <source>Move / Copy Options</source>
        <translation>移動/コピーオプション</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>コピーの数</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;D オリジナルを削除</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>&amp;K オリジナルを維持</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>&amp;M 多重コピー</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>&amp;a 現在の画層と属性を使用</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Translate/ts/Translate_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Translate</name>
    <message>
        <location filename="../Translate.js" line="+44"/>
        <source>Modify</source>
        <translation>更新</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Move/Copy</source>
        <translation>移動/コピー</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Reference point</source>
        <translation>基準点</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Target point</source>
        <translation>ターゲット点</translation>
    </message>
    <message>
        <location filename="../TranslateInit.js" line="+2"/>
        <source>&amp;Move / Copy</source>
        <translation>&amp;M 移動/コピー</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Move or copy entities once or multiple times</source>
        <translation>１回または複数回の移動またはコピー</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Use dialog for tool options</source>
        <translation>ツールオプションのためダイアログを使用</translation>
    </message>
    <message>
        <location filename="../Translate.ui" line="+17"/>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies:</source>
        <translation>コピーの数:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>現在のレイヤーと属性を使用</translation>
    </message>
</context>
<context>
    <name>TranslateOptions</name>
    <message>
        <location filename="../TranslateDialog.ui" line="+14"/>
        <source>Move / Copy Options</source>
        <translation>移動/コピーオプション</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>コピーの数</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;D オリジナルを削除</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>&amp;K オリジナルを維持</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>&amp;M 多重コピー</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>&amp;a 現在の画層と属性を使用</translation>
    </message>
</context>
</TS>
